@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -49,37 +50,25 @@
 #include <tox.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/app.hxx>
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
 #include <wrtsh.hxx>
-#ifndef _BASESH_HXX
 #include <basesh.hxx>
-#endif
 #include <uitool.hxx>
 #include <viewopt.hxx>
 #include <tablemgr.hxx>
 #include <pagedesc.hxx>
-#ifndef _WVIEW_HXX
 #include <wview.hxx>
-#endif
 #include <globdoc.hxx>
 #include <svl/stritem.hxx>
 #include <unotools/moduleoptions.hxx>
 #include <svl/visitem.hxx>
 
-#ifndef _CMDID_H
 #include <cmdid.h>
-#endif
 
 #include <IDocumentRedlineAccess.hxx>
 
 using namespace ::com::sun::star;
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwView::GetState(SfxItemSet &rSet)
 {
     SfxWhichIter aIter(rSet);
@@ -443,11 +432,6 @@ void SwView::GetState(SfxItemSet &rSet)
     }
 }
 
-
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwView::GetDrawState(SfxItemSet &rSet)
 {
     SfxWhichIter aIter(rSet);
@@ -513,10 +497,6 @@ void SwView::GetDrawState(SfxItemSet &rSet)
         }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 sal_Bool SwView::HasUIFeature( sal_uInt32 nFeature )
 {
     sal_Bool bRet = sal_False;
@@ -528,3 +508,4 @@ sal_Bool SwView::HasUIFeature( sal_uInt32 nFeature )
     return bRet;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
