@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,7 +31,7 @@
 
 
 #include <swtypes.hxx>
-#include <tools/debug.hxx>
+#include <osl/diagnose.h>
 #include <unomod.hxx>
 #include <unomid.h>
 #include <unoprnms.hxx>
@@ -42,7 +43,7 @@
 #include <docsh.hxx>
 #include <wrtsh.hxx>
 #include <viewopt.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <com/sun/star/text/NotePrintMode.hpp>
 #include <doc.hxx>
@@ -53,7 +54,6 @@
 #include <edtwin.hxx>
 #include <rtl/ustrbuf.hxx>
 
-
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::beans;
@@ -106,6 +106,7 @@ enum SwViewSettingsPropertyHandles
     HANDLE_VIEWSET_HORI_RULER_METRIC,
     HANDLE_VIEWSET_VERT_RULER_METRIC
 };
+
 enum SwPrintSettingsPropertyHandles
 {
     HANDLE_PRINTSET_ANNOTATION_MODE,
@@ -177,6 +178,7 @@ static ChainablePropertySetInfo * lcl_createViewSettingsInfo()
     };
     return new ChainablePropertySetInfo ( aViewSettingsMap_Impl );
 }
+
 static ChainablePropertySetInfo * lcl_createPrintSettingsInfo()
 {
     static PropertyInfo aPrintSettingsMap_Impl[] =
@@ -207,85 +209,66 @@ static ChainablePropertySetInfo * lcl_createPrintSettingsInfo()
 /******************************************************************
  * SwXModule
  ******************************************************************/
-/* -----------------30.03.99 15:10-------------------
- *
- * --------------------------------------------------*/
 Reference< uno::XInterface > SAL_CALL SwXModule_createInstance(
     const Reference< XMultiServiceFactory > & /*rSMgr*/) throw( Exception )
 {
     static Reference< uno::XInterface >  xModule = (cppu::OWeakObject*)new SwXModule();;
     return xModule;
 }
-/* -----------------------------17.04.01 13:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence< OUString > SAL_CALL SwXModule_getSupportedServiceNames() throw()
 {
     OUString sService( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.GlobalSettings"));
     const Sequence< OUString > aSeq( &sService, 1 );
     return aSeq;
 }
-/* -----------------------------17.04.01 13:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 OUString SAL_CALL SwXModule_getImplementationName() throw()
 {
     return OUString( RTL_CONSTASCII_USTRINGPARAM("SwXModule" ) );
 }
-/*-- 17.12.98 12:19:01---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXModule::SwXModule() :
     pxViewSettings(0),
     pxPrintSettings(0)
 {
 }
-/*-- 17.12.98 12:19:02---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXModule::~SwXModule()
 {
     delete pxViewSettings;
     delete pxPrintSettings;
 }
-/*-- 17.12.98 12:19:03---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Reference< XPropertySet >  SwXModule::getViewSettings(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     if(!pxViewSettings)
     {
         ((SwXModule*)this)->pxViewSettings = new Reference< XPropertySet > ;
-        DBG_ERROR("Web oder Text?");
+        OSL_ENSURE(false, "Web or Text?");
         *pxViewSettings = static_cast < HelperBaseNoState * > ( new SwXViewSettings( sal_False, 0 ) );
     }
     return *pxViewSettings;
 }
-/*-- 17.12.98 12:19:03---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 Reference< XPropertySet >  SwXModule::getPrintSettings(void) throw( uno::RuntimeException )
 {
-    ::vos::OGuard aGuard(Application::GetSolarMutex());
+    SolarMutexGuard aGuard;
     if(!pxPrintSettings)
     {
         ((SwXModule*)this)->pxPrintSettings = new Reference< XPropertySet > ;
-        DBG_ERROR("Web oder Text?");
+        OSL_ENSURE(false, "Web or Text?");
         *pxPrintSettings = static_cast < HelperBaseNoState * > ( new SwXPrintSettings ( PRINT_SETTINGS_MODULE ) );
     }
     return *pxPrintSettings;
 }
-/* -----------------------------06.04.00 10:59--------------------------------
 
- ---------------------------------------------------------------------------*/
 OUString SwXModule::getImplementationName(void) throw( RuntimeException )
 {
     return SwXModule_getImplementationName();
 }
-/* -----------------------------06.04.00 10:59--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Bool SwXModule::supportsService(const OUString& rServiceName) throw( RuntimeException )
 {
     const Sequence< OUString > aNames = SwXModule_getSupportedServiceNames();
@@ -296,9 +279,7 @@ sal_Bool SwXModule::supportsService(const OUString& rServiceName) throw( Runtime
     }
     return FALSE;
 }
-/* -----------------------------06.04.00 10:59--------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence< OUString > SwXModule::getSupportedServiceNames(void) throw( RuntimeException )
 {
     return SwXModule_getSupportedServiceNames();
@@ -307,9 +288,6 @@ Sequence< OUString > SwXModule::getSupportedServiceNames(void) throw( RuntimeExc
 /******************************************************************
  * SwXPrintSettings
  ******************************************************************/
-/*-- 17.12.98 12:54:04---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwXPrintSettings::SwXPrintSettings(SwXPrintSettingsType eType, SwDoc* pDoc)
 : ChainableHelperNoState ( lcl_createPrintSettingsInfo (), &Application::GetSolarMutex() )
 , meType(eType)
@@ -317,9 +295,7 @@ SwXPrintSettings::SwXPrintSettings(SwXPrintSettingsType eType, SwDoc* pDoc)
 , mpDoc ( pDoc )
 {
 }
-/*-- 17.12.98 12:54:05---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXPrintSettings::~SwXPrintSettings()
     throw()
 {
@@ -481,6 +457,7 @@ void SwXPrintSettings::_setSingleValue( const comphelper::PropertyInfo & rInfo,
             throw UnknownPropertyException();
     }
 }
+
 void SwXPrintSettings::_postSetValues ()
     throw(UnknownPropertyException, PropertyVetoException, IllegalArgumentException, WrappedTargetException )
 {
@@ -513,6 +490,7 @@ void SwXPrintSettings::_preGetValues ()
         break;
     }
 }
+
 void SwXPrintSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, uno::Any & rValue )
     throw(UnknownPropertyException, WrappedTargetException )
 {
@@ -586,28 +564,23 @@ void SwXPrintSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo,
             throw UnknownPropertyException();
     }
 }
+
 void SwXPrintSettings::_postGetValues ()
     throw(UnknownPropertyException, PropertyVetoException, IllegalArgumentException, WrappedTargetException )
 {
     mpPrtOpt = NULL;
 }
-/* -----------------------------06.04.00 11:02--------------------------------
 
- ---------------------------------------------------------------------------*/
 OUString SwXPrintSettings::getImplementationName(void) throw( RuntimeException )
 {
     return C2U("SwXPrintSettings");
 }
-/* -----------------------------06.04.00 11:02--------------------------------
 
- ---------------------------------------------------------------------------*/
 sal_Bool SwXPrintSettings::supportsService(const OUString& rServiceName) throw( RuntimeException )
 {
     return C2U("com.sun.star.text.PrintSettings") == rServiceName;
 }
-/* -----------------------------06.04.00 11:02--------------------------------
 
- ---------------------------------------------------------------------------*/
 Sequence< OUString > SwXPrintSettings::getSupportedServiceNames(void) throw( RuntimeException )
 {
     Sequence< OUString > aRet(1);
@@ -616,13 +589,6 @@ Sequence< OUString > SwXPrintSettings::getSupportedServiceNames(void) throw( Run
     return aRet;
 }
 
-
-/******************************************************************
- *
- ******************************************************************/
-/*-- 18.12.98 11:01:10---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwXViewSettings::SwXViewSettings(sal_Bool bWebView, SwView*	pVw)
 : ChainableHelperNoState( lcl_createViewSettingsInfo (), &Application::GetSolarMutex() )
 , pView(pVw)
@@ -640,14 +606,13 @@ SwXViewSettings::SwXViewSettings(sal_Bool bWebView, SwView*	pVw)
         mpInfo->remove ( OUString ( RTL_CONSTASCII_USTRINGPARAM ( "HelpURL" ) ) );
 
 }
-/*-- 18.12.98 11:01:10---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwXViewSettings::~SwXViewSettings()
     throw()
 {
 
 }
+
 void SwXViewSettings::_preSetValues ()
     throw(UnknownPropertyException, PropertyVetoException, IllegalArgumentException, WrappedTargetException )
 {
@@ -666,6 +631,7 @@ void SwXViewSettings::_preSetValues ()
     if(pView)
         mpViewOption->SetStarOneSetting(sal_True);
 }
+
 void SwXViewSettings::_setSingleValue( const comphelper::PropertyInfo & rInfo, const uno::Any &rValue )
     throw(UnknownPropertyException, PropertyVetoException, IllegalArgumentException, WrappedTargetException )
 {
@@ -775,8 +741,8 @@ void SwXViewSettings::_setSingleValue( const comphelper::PropertyInfo & rInfo, c
                 break;
                 default:
                     throw IllegalArgumentException(
-                        ::rtl::OUString::createFromAscii(
-                            "SwXViewSettings: invalid zoom type"), 0, 0);
+                        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                            "SwXViewSettings: invalid zoom type")), 0, 0);
                 break;
             }
             if(eZoom < USHRT_MAX)
@@ -889,6 +855,7 @@ void SwXViewSettings::_preGetValues ()
     else
         mpConstViewOption = SW_MOD()->GetViewOption(bWeb);
 }
+
 void SwXViewSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, uno::Any & rValue )
     throw(UnknownPropertyException, WrappedTargetException )
 {
@@ -918,7 +885,7 @@ void SwXViewSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, u
         case  HANDLE_VIEWSET_TABSTOPS              :   bBoolVal = mpConstViewOption->IsTab(sal_True);	break;
         case  HANDLE_VIEWSET_BREAKS                :   bBoolVal = mpConstViewOption->IsLineBreak(sal_True); break;
         case  HANDLE_VIEWSET_HIDDEN_TEXT           :   bBoolVal = mpConstViewOption->IsShowHiddenField();   break;
-        case  HANDLE_VIEWSET_HIDDEN_CHARACTERS     :   bBoolVal = mpConstViewOption->IsShowHiddenChar(); break;
+        case  HANDLE_VIEWSET_HIDDEN_CHARACTERS     :   bBoolVal = mpConstViewOption->IsShowHiddenChar(sal_True); break;
         case  HANDLE_VIEWSET_HIDDEN_PARAGRAPHS     :   bBoolVal = mpConstViewOption->IsShowHiddenPara();	break;
         case  HANDLE_VIEWSET_TABLE_BOUNDARIES      :   bBoolVal = SwViewOption::IsTableBoundaries(); break;
         case  HANDLE_VIEWSET_TEXT_BOUNDARIES       :   bBoolVal = SwViewOption::IsDocBoundaries(); break;
@@ -1026,11 +993,12 @@ void SwXViewSettings::_getSingleValue( const comphelper::PropertyInfo & rInfo, u
             bBool = sal_False;
         }
         break;
-        default: DBG_ERROR("Diese Id gibt's nicht!");
+        default: OSL_ENSURE(false, "there is no such ID!");
     }
     if( bBool )
         rValue.setValue(&bBoolVal, ::getBooleanCppuType());
 }
+
 void SwXViewSettings::_postGetValues ()
     throw(UnknownPropertyException, PropertyVetoException, IllegalArgumentException, WrappedTargetException )
 {
@@ -1055,3 +1023,4 @@ Sequence< OUString > SwXViewSettings::getSupportedServiceNames(void) throw( Runt
     return aRet;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
